"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
---------------------------------------------------------------------
---------------------------------------------------------------------
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PrecisionDuration(google.protobuf.message.Message):
    """Represents a duration of time expressed in NI Binary Time Format (NI-BTF).

    https://www.ni.com/docs/en-US/bundle/labwindows-cvi/page/cvi/libref/ni-btf.htm
    A PrecisionDuration is encoded as a count of seconds and fractions of seconds at
    2^-64 resolution.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECONDS_FIELD_NUMBER: builtins.int
    FRACTIONAL_SECONDS_FIELD_NUMBER: builtins.int
    seconds: builtins.int
    """The number of seconds."""
    fractional_seconds: builtins.int
    """Non-negative fractions of a second at 2^-64 resolution."""
    def __init__(
        self,
        *,
        seconds: builtins.int = ...,
        fractional_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fractional_seconds", b"fractional_seconds", "seconds", b"seconds"]) -> None: ...

global___PrecisionDuration = PrecisionDuration
