"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ni.protobuf.types.attribute_value_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Scalar(google.protobuf.message.Message):
    """A scalar value with associated attributes, such as units."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class AttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> ni.protobuf.types.attribute_value_pb2.AttributeValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: ni.protobuf.types.attribute_value_pb2.AttributeValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTRIBUTES_FIELD_NUMBER: builtins.int
    DOUBLE_VALUE_FIELD_NUMBER: builtins.int
    SINT32_VALUE_FIELD_NUMBER: builtins.int
    BOOL_VALUE_FIELD_NUMBER: builtins.int
    STRING_VALUE_FIELD_NUMBER: builtins.int
    double_value: builtins.float
    sint32_value: builtins.int
    bool_value: builtins.bool
    string_value: builtins.str
    @property
    def attributes(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, ni.protobuf.types.attribute_value_pb2.AttributeValue]:
        """The names and values of all scalar attributes.

        A scalar attribute is metadata attached to a scalar.
        It is represented in this message as a map associating the name of
        the attribute with the value described by AttributeValue.
        """

    def __init__(
        self,
        *,
        attributes: collections.abc.Mapping[builtins.str, ni.protobuf.types.attribute_value_pb2.AttributeValue] | None = ...,
        double_value: builtins.float = ...,
        sint32_value: builtins.int = ...,
        bool_value: builtins.bool = ...,
        string_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bool_value", b"bool_value", "double_value", b"double_value", "sint32_value", b"sint32_value", "string_value", b"string_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["attributes", b"attributes", "bool_value", b"bool_value", "double_value", b"double_value", "sint32_value", b"sint32_value", "string_value", b"string_value", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["double_value", "sint32_value", "bool_value", "string_value"] | None: ...

global___Scalar = Scalar
